You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@subversion.apache.org by br...@apache.org on 2013/10/21 09:03:54 UTC

svn commit: r1534045 - in /subversion/trunk/subversion: include/svn_ra.h libsvn_client/merge.c libsvn_client/mergeinfo.c

Author: brane
Date: Mon Oct 21 07:03:54 2013
New Revision: 1534045

URL: http://svn.apache.org/r1534045
Log:
Replace use of deprecated svn_ra_get_log2 in a couple of places.

* subversion/include/svn_ra.h (svn_ra_get_log2): Fix docstring.
* subversion/libsvn_client/merge.c (get_log): Use svn_ra_get_log3.
* subversion/libsvn_client/mergeinfo.c
  (logs_for_mergeinfo_rangelist): Likewise.

Modified:
    subversion/trunk/subversion/include/svn_ra.h
    subversion/trunk/subversion/libsvn_client/merge.c
    subversion/trunk/subversion/libsvn_client/mergeinfo.c

Modified: subversion/trunk/subversion/include/svn_ra.h
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/include/svn_ra.h?rev=1534045&r1=1534044&r2=1534045&view=diff
==============================================================================
--- subversion/trunk/subversion/include/svn_ra.h (original)
+++ subversion/trunk/subversion/include/svn_ra.h Mon Oct 21 07:03:54 2013
@@ -1621,7 +1621,7 @@ svn_ra_get_log3(svn_ra_session_t *sessio
 
 /**
  * Similar to svn_ra_get_log3(), but with @a move_behavior being set to
- * #svn_fs_move_behavior_no_moves.
+ * #svn_move_behavior_no_moves.
  *
  * @since New in 1.5.
  * @deprecated Provided for backward compatibility with the 1.8 API.

Modified: subversion/trunk/subversion/libsvn_client/merge.c
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_client/merge.c?rev=1534045&r1=1534044&r2=1534045&view=diff
==============================================================================
--- subversion/trunk/subversion/libsvn_client/mergeinfo.c (original)
+++ subversion/trunk/subversion/libsvn_client/mergeinfo.c Mon Oct 21 07:03:54 2013
@@ -1566,13 +1566,14 @@ logs_for_mergeinfo_rangelist(const char 
     target = apr_array_make(scratch_pool, 1, sizeof(const char *));
     APR_ARRAY_PUSH(target, const char *) = "";
 
-    SVN_ERR(svn_ra_get_log2(ra_session, target,
+    SVN_ERR(svn_ra_get_log3(ra_session, target,
                             oldest_revs_first ? oldest_rev : youngest_rev,
                             oldest_revs_first ? youngest_rev : oldest_rev,
                             0 /* limit */,
                             discover_changed_paths,
                             FALSE /* strict_node_history */,
                             FALSE /* include_merged_revisions */,
+                            svn_move_behavior_no_moves, /* ### really? */
                             revprops,
                             filter_log_entry_with_rangelist, &fleb,
                             scratch_pool));
--- subversion/trunk/subversion/libsvn_client/merge.c (original)
+++ subversion/trunk/subversion/libsvn_client/merge.c Mon Oct 21 07:03:54 2013
@@ -6729,7 +6729,7 @@ merge_range_find_extremes(svn_revnum_t *
     }
 }
 
 /* Wrapper around svn_ra_get_log2(). Invoke RECEIVER with RECEIVER_BATON
  * on each commit from YOUNGEST_REV to OLDEST_REV in which TARGET_RELPATH
  * changed.  TARGET_RELPATH is relative to RA_SESSION's URL.
  * Important: Revision properties are not retrieved by this function for
@@ -6753,10 +6753,11 @@ get_log(svn_ra_session_t *ra_session,
 
   revprops = apr_array_make(pool, 0, sizeof(const char *));
 
-  SVN_ERR(svn_ra_get_log2(ra_session, log_targets, youngest_rev,
+  SVN_ERR(svn_ra_get_log3(ra_session, log_targets, youngest_rev,
                           oldest_rev, 0 /* limit */, discover_changed_paths,
                           FALSE /* strict_node_history */,
                           FALSE /* include_merged_revisions */,
+                          svn_move_behavior_no_moves, /* ### really? */
                           revprops, receiver, receiver_baton, pool));
 
   return SVN_NO_ERROR;
@@ -6729,7 +6729,7 @@ merge_range_find_extremes(svn_revnum_t *
 }
 
-/* Wrapper around svn_ra_get_log2(). Invoke RECEIVER with RECEIVER_BATON
+/* Wrapper around svn_ra_get_log3(). Invoke RECEIVER with RECEIVER_BATON
  * on each commit from YOUNGEST_REV to OLDEST_REV in which TARGET_RELPATH
  * changed.  TARGET_RELPATH is relative to RA_SESSION's URL.

Modified: subversion/trunk/subversion/libsvn_client/mergeinfo.c
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_client/mergeinfo.c?rev=1534045&r1=1534044&r2=1534045&view=diff
==============================================================================